// Common structures and values shared by BB and plugins


#pragma once


#pragma pack(push)
#pragma pack(4)		// Make sure BB and plugin are using the same packing


const int BBSignature = 0xbb0bb0bb;		// Identify BB

enum BB_Errors
{
	BBE_NoError = 0,		// Call SetLastError with this to clear the last error
	BBE_InvalidPointer,		// You passed a null pointer when valid data was required
	BBE_BufferTooSmall,		// The data won't fit in the buffer you supplied
	BBE_SessionNotFound,	// No session found
	BBE_InvalidHandle		// The handle was NULL or not found
};

enum BBSP_Mask_Flags	// Bits for mask element of BBSP struct
{
	SPF_List = 0x1,
	SPF_Search = 0x2,
	SPF_Filter = 0x4,
	SPF_AutoStart = 0x8,
	SPF_AutoMode = 0x10,
	SPF_AutoDestroy = 0x20,
	SPF_AutoHangUp = 0x40,
	SPF_AutoNext = 0x80,
	SPF_Duration = 0x100,
	SPF_AutoLoop = 0x200,
	SPF_StartingPoint = 0x400,
	SPF_LastVal = 0x800,
	SPF_LastNewVal = 0x1000
};


enum BBSP_Starting_Points
{
	SP_New = 0,
	SP_All = 1,
	SP_Last = 2,
	SP_LastNew = 3
};

// Structure for launching or modifying a search session
typedef struct tagBBSP //Binary Boy Search parameters
{
    UINT    mask;		// Set a bit for each valid element (see BBSP_Mask_Bits)
	LPCTSTR	pList;		// Grouplist filename without the path.  Example: mylist.lst
	LPCTSTR	pSearch;	// Search string. Example: .jpg OR .gif
	LPCTSTR	pFilter;	// Filter string. Example: "make money fast"
	bool	bAutoStart;	// Download subjects when session starts.
	bool	bAutoMode;	// Auto download all matching articles from each group
	bool	bAutoDestroy;//Close session when last group finished
	bool	bAutoHangUp;// Hang up the modem when session closes
	bool	bAutoNext;	// Auto skip groups that contain no results
	int		nDuration;	// Time limit in seconds for auto searches. 0 = infinite
	bool	bAutoLoop;	// Return to first newsgroup after reaching the last
	int		nStartingPoint;// SP_New, SP_All, SP_Last or SP_LastNew
	int		nLastVal;	// Value for "Download last nnnn" starting point
	int		nLastNewVal;// Value for "Download last nnnn new" starting point
} BBSP, *LPBBSP;


enum BBMessages
{
	BB_SetMenuText = WM_APP+100,	// wParam = id, lParam = char* menu text
	BB_StartSearch = WM_APP+101,    // Open a search session. wParam = id, lParam = BBSP struct. Returns true on success.  false on error
	BB_StopSearch = WM_APP+102,		// Stop search  wParam = id, lParam = 0
 	BB_ChangeSearch = WM_APP+103,   // Change search options of an open session.  wParam = id, lParam = BBSP struct
	BB_GetQueueCount = WM_APP+104,  // Returns number of items in queue  wParam = id, lParam = 0
	BB_IsQueueEmpty = WM_APP+105,   // Returns true if queue is empty, false otherwise  wParam = id, lParam = 0
	BB_GoSearch = WM_APP+106,		// Continue downloading.  Same as Go button on progress tab wParam = id, lParam = 0
	BB_CloseSearch = WM_APP+107,	// Close the search session. wParam = id, lParam = 0
	BB_RefreshSearch = WM_APP+108,	// Refresh. wParam = id, lParam = 0 refresh online, 1 refresh from cache
	BB_AddTwit = WM_APP+109,		// Add a rule to the twit file. wParam = id, lParam = email address or search string
	BB_GetLastError = WM_APP+110,	// Returns the last error triggered by this plugin. wParm = id, lParam = 0
	BB_SetLastError = WM_APP+111,	// Sets the last error.  wParam = id, lParam = 0
	BB_EnumGroupLists = WM_APP+112,	// Enumerates all group list filenames.  wParam = id, lParam = callback info
	BB_GetCurrentGroup = WM_APP+113 // Gets name of newsgroup. wParam = id, lParam = STRINGBUFFER
};



typedef struct tagBBINFO
{
    DWORD   dwSize;    //    Size of structure
    DWORD   dwSign;    //    BBSignature
    DWORD   dwMajor;
    DWORD   dwMinor;
    DWORD   dwBuild;
    HWND    hWnd;		// Main window
    HMENU	hMenu;      // Menu of main window
    LPCTSTR pInstallFolder;	// Where binboy.exe is
    LPCTSTR pPluginsFolder; // Where this plugin was loaded from
	HWND	hStatus;	// Statusbar on main window
	int		nId;		// A unique id for this plugin
} BBINFO, *LPBBINFO ;

// Function type that receives the callback from the BB_EnumGroupLists command
typedef bool (CALLBACK *fnEnumGroupListsProc)(const char*, LPARAM);

typedef struct tagENUMGROUPLISTSINFO
{
	fnEnumGroupListsProc EnumGroupListsProc;	// Function to call back
	LPARAM lParam;								// An identifier such as a 'this' pointer
}ENUMGROUPLISTSINFO, *LPENUMGROUPLISTSINFO;

typedef struct tagBBSTRINGBUFFER
{
	DWORD dwBufSize;	// Buffer size
	LPTSTR pBuffer;		// Pointer to buffer to copy text to.
} BBSTRINGBUFFER, *LPBBSTRINGBUFFER;

typedef void* HNEWSGROUP; // Handle for a newsgroup created by a plugin.
typedef void* HGROUPLIST;// Handle for a group list. created by a plugin.

#pragma pack(pop)

