// bbplugin.cpp : Defines the entry point for the DLL application.
//
// Instructions - Compile this into a DLL.  Then copy it to the Plugins subfolder
// under the Binary Boy program folder.  For example: c:\program files\binary boy\Plugins\MyPlugin.dll

#include "stdafx.h"
#include <iostream>
#include <sstream>
#include "bbplugin.h"

int g_nId = 0;
HWND g_hBB;

BOOL APIENTRY DllMain( HANDLE hModule, 
                       DWORD  ul_reason_for_call, 
                       LPVOID lpReserved
					 )
{
	switch (ul_reason_for_call)
	{
	case DLL_PROCESS_ATTACH:
	case DLL_THREAD_ATTACH:
	case DLL_THREAD_DETACH:
	case DLL_PROCESS_DETACH:
		break;
	}
    return TRUE;
}

// This function will receive the filename of each group list
// lParam is the value you passed with the BB_EnumGroupsLists command
// Return value: true to continue. false to stop early
bool CALLBACK GroupListsProc(const char* pFilename, LPARAM lParam)
{
	MessageBox(NULL, pFilename, "Enum", MB_OK);
	return true;
}

// OnInit is called for every DLL immediately after it loads.
// Return value: Must be false.
BBPLUGIN_API bool OnInit()
{

	MessageBox(NULL, "OnInit", "Sample - OnInit", MB_OK);
	return false;
}

// OnSettings is called when the Plugin's item is clicked under the BB Plugin menu
// Return value: Must be false.
BBPLUGIN_API bool OnSettings()
{
/*
// Gets the current group list name
	BBSTRINGBUFFER s;
	char buf[512];
	buf[0] = '\0';
	s.dwBufSize = sizeof(buf);
	s.pBuffer = &buf[0];
	SendMessage(g_hBB, BB_GetCurrentGroup, g_nId, (LPARAM) &s);
	MessageBox(NULL, s.pBuffer, "Current group", MB_OK);

*/


	MessageBox(NULL, "OnSettings", "Sample - OnSettings", MB_OK);
	return false;
}


// OnStart is called after the settings are loaded and the main
// window is created.
// bbinfo - A BBINFO struct containing version numbers and paths.
//          The pointers in BBINFO are temporary and will be invalid
//          after this call returns.  Copy the data elsewhere if
//          you wish to use it later.
// Return value: Must be false.
BBPLUGIN_API bool OnStart(BBINFO* bbinfo)
{
	std::stringstream ss;
	ss << "Version " << bbinfo->dwMajor << "." << bbinfo->dwMinor << "." << bbinfo->dwBuild << std::endl;
	ss << "dwSize: " << bbinfo->dwSize << std::endl;
	ss << "Signature: " << std::hex << bbinfo->dwSign << std::endl;
	ss << "hWnd: " << std::hex << bbinfo->hWnd << std::endl;
	ss << "hMenu: " << std::hex << bbinfo->hMenu << std::endl;
	ss << "BB Folder: " << bbinfo->pInstallFolder << std::endl;
	ss << "Plugins Folder: " << bbinfo->pPluginsFolder << std::endl;
	ss << "hStatus: " << std::hex << bbinfo->hStatus << std::endl;
	ss << "nId: " << std::dec << bbinfo->nId << std::endl;

	g_nId = bbinfo->nId;		// Save this plugin's id so BB knows which one is calling
	g_hBB = bbinfo->hWnd;	// Save the BB window handle.
	SendMessage(g_hBB, BB_SetMenuText, g_nId, (LPARAM) "Sample Plugin");

	MessageBox(NULL, ss.str().c_str(), "Sample - OnStart", MB_OK);

// To launch a search, fill in the relevant BBSP structure members, set the mask
// for the members you set and send a BBStartSearch message to Binary Boy.

/*
//	Uncomment this to launch a manual search
	BBSP b;
	b.bAutoStart = true;
	b.nLastVal = 1000;
	b.nStartingPoint = SP_Last;
	b.pSearch = "*.*";
	b.pList = "sample.lst";		// Use the sample.lst grouplist
	b.mask = SPF_AutoStart|SPF_LastVal|SPF_StartingPoint|SPF_Search|SPF_List;
	SendMessage(g_hBB, BB_StartSearch, g_nId, (LPARAM)&b);
*/

/*
//	Uncomment this to start an auto search
	BBSP b;
	b.bAutoStart = true;		// Refresh the first newsgroup when the session starts
	b.nLastVal = 1000;			// Download 1000 subjects
	b.nStartingPoint = SP_Last; // Download last nnn subjects
	b.pSearch = "*.*";			// Search for *.*
	b.pList = "sample.lst";		// Use the sample.lst grouplist
	b.bAutoMode = true;			// Auto search and download from all groups in list
	b.mask = SPF_AutoStart|SPF_LastVal|SPF_StartingPoint|SPF_Search|SPF_List|SPF_AutoMode;
	SendMessage(g_hBB, BB_StartSearch, g_nId, (LPARAM)&b);
*/

/*
// Uncomment this to send all group list filenames to the GroupListsProc function
	ENUMGROUPLISTSINFO e;
	e.EnumGroupListsProc = GroupListsProc;
	e.lParam = 1;
	SendMessage(g_hBB, BB_EnumGroupLists, g_nId, (LPARAM) &e);
*/
	return false;

}


// Display the file after Binary Boy decodes.
// pFile - The full path to the file
// pFrom - The email address of the poster
// pFirstPart - Either part 0 or part 1 of the set
// Return value: false to let the internal viewer display or true if this plugin displays
//               the file.
BBPLUGIN_API bool OnViewFile(const char* pFile, const char* pFrom, const char* pFirstPart)
{
	std::stringstream ss;
	ss << "File \"" << pFile << "\" from: \"" << pFrom << "\"" << std::endl;
	ss << "First Part: " << pFirstPart;
	MessageBox(NULL, ss.str().c_str(), "Sample - View a file", MB_OK);
	return false;
}

// Display the file after Binary Boy decodes.
// pFile - The full path to the file
// pFrom - The email address of the poster
// pFirstPart - Either part 0 or part 1 of the set
// Return value: false
BBPLUGIN_API bool OnFileDecoded(const char* pFile, const char* pFrom, const char* pFirstPart)
{
	std::stringstream ss;
	ss << "File \"" << pFile << "\" from: \"" << pFrom << "\"" << std::endl;
	ss << "First Part: " << pFirstPart;
	MessageBox(NULL, ss.str().c_str(), "Sample - OnFileDecoded", MB_OK);
	return false;
}

// This function is called when Binary Boy begins shutting down.
// It is called for every plugin even if other plugins return true
// Return value: Must be false
BBPLUGIN_API bool OnExit()
{
	MessageBox(NULL, "Binary Boy is exiting.", "Sample - OnExit", MB_OK);
	return false;
}

